.. _modules:

==============
API References
==============

This is the class and function reference of nilearn. Please refer to
the :ref:`user guide <user_guide>` for more information and usage examples.

.. toctree::
   :maxdepth: 1

   connectome.rst
   datasets.rst
   decoding.rst
   decomposition.rst
   glm.rst
   image.rst
   interfaces.rst
   maskers.rst
   masking.rst
   mass_univariate.rst
   plotting.rst
   regions.rst
   reporting.rst
   signal.rst
   surface.rst
